@@ -36,7 +36,7 @@ setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 
-class BuilderConditions(object):
+class BuilderConditions():
     @staticmethod
     def was_installed(pkg, task_name):
         def func(Get):
