@@ -27,7 +27,7 @@ from calculate.lib.utils.portage import getSquashList, isPkgInstalled
 from calculate.lib.variables.system import RootType
 import calculate.update.variables.update as update
 from .action import Actions
-import linux as vars_linux
+from . import linux as vars_linux
 import datetime
 from calculate.install import distr
 import calculate.lib.utils.device as device
@@ -789,8 +789,7 @@ class VariableClBuilderParentPath(ReadonlyVariable):
 
     def get(self):
         builder_path = self.Get('cl_builder_path')
-        return ("../" * len(filter(None,
-                                   builder_path.split('/'))))[:-1]
+        return ("../" * len([x for x in builder_path.split('/') if x]))[:-1]
 
 
 class VariableClBuilderStageSet(ReadonlyVariable):
@@ -922,7 +921,7 @@ class VariableClBuilderImageFilename(Variable):
                 isoname = "%s-%s-%s%s" % (shortname, buildnumber,
                                           arch, suffix)
             fullname = ""
-            for i_dn in filter(None, (addon_dn, dn)):
+            for i_dn in (x for x in (addon_dn, dn) if x):
                 fullname = path.join(i_dn, isoname)
                 if not rewrite and path.exists(fullname):
                     break
@@ -1201,6 +1200,10 @@ class KernelData(ReadonlyVariable):
 
     def get_files_by_type(self, pathname, descr):
         ftype = typeFile(magic=0x4).getMType
+        # print("DEBUG get files by type")
+        # print("pathname: ", pathname)
+        # print("listDirectory: ", listDirectory(pathname, fullPath=True))
+        # raise Exception(f"path: {pathname}")
         for x in listDirectory(pathname, fullPath=True):
             if descr in ftype(x):
                 yield x
@@ -1595,7 +1598,7 @@ class VariableClLivemenuPath(ReadonlyVariable):
 
     def get(self):
         data = readFile(self.grub_config)
-        m = re.search('^livepath=([^\n]+)', data, re.M)
+        m = re.search(r'^livepath=([^\n]+)', data, re.M)
         if m:
             return m.group(1).strip("'\"")
         return ""
